==> haskell-cabal-install-parsers-0.4.2-147-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cabal-install-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cabal-install-parsers
version:              0.4.2
visibility:           public
id:                   cabal-install-parsers-0.4.2-6RfL9rUZtZ25t56uY7Z8Ho
key:                  cabal-install-parsers-0.4.2-6RfL9rUZtZ25t56uY7Z8Ho
license:              GPL-2.0-or-later AND BSD-3-Clause
maintainer:           hvr@gnu.org, oleg.grenrus@iki.fi
author:               Herbert Valerio Riedel, Oleg Grenrus
homepage:             https://haskell-ci.rtfd.org/
synopsis:             Utilities to work with cabal-install files
description:
    @cabal-install-parsers@ provides parsers for @cabal-install@ files:
    @cabal.project@ ("Cabal.Project"),
    @cabal.config@ ("Cabal.Config"),
    @01-index.tar@ ("Cabal.Index");
    as well as some other utilities.

    The feature set is mainly motivated by the needs of @haskell-ci@ package.
    The parsed data is not complete, functionality is added on demand.

category:             Development
abi:                  7b06afe31961639a4271d44b05c705b3
exposed:              True
exposed-modules:
    Cabal.Config Cabal.Index Cabal.Optimization Cabal.Package
    Cabal.Parse Cabal.Project Cabal.SourceRepo

hidden-modules:       Cabal.Internal.Glob Cabal.Internal.Newtypes
import-dirs:          /usr/lib/ghc-9.0.2/site-local/cabal-install-parsers-0.4.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cabal-install-parsers-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cabal-install-parsers
hs-libraries:         HScabal-install-parsers-0.4.2-6RfL9rUZtZ25t56uY7Z8Ho
depends:
    Cabal-3.4.1.0 aeson-1.5.6.0-AKViGrmijRVB0tE3IZiiOh base-4.15.1.0
    base16-bytestring-1.0.2.0-3t1eKOwEZc4L6WqKEMpVDW binary-0.8.8.0
    binary-instances-1.0.2-ESOCw6BDDn4KCjMN1E5ETk bytestring-0.10.12.1
    containers-0.6.4.1
    cryptohash-sha256-0.11.102.1-4uKODbETe2jEdgqITdfJ54 deepseq-1.4.5.0
    directory-1.3.6.2 filepath-1.4.2.1
    lukko-0.1.1.3-37sXjVWjqlg5XDVeMBc0uC
    network-uri-2.6.4.1-DpIvCtUeaVVBZXUmMpeWC3 parsec-3.1.14.0
    pretty-1.1.3.6 tar-0.5.1.1-AsJwz1f9xLD88KBiyKi4N0 text-1.2.5.0
    time-1.9.3 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cabal-install-parsers/html/cabal-install-parsers.haddock

haddock-html:         /usr/share/doc/haskell-cabal-install-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cabal-install-parsers-0.4.2-156-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cabal-install-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cabal-install-parsers
version:              0.4.2
visibility:           public
id:                   cabal-install-parsers-0.4.2-AleMxSwMpbyL0nCLZ1pfzG
key:                  cabal-install-parsers-0.4.2-AleMxSwMpbyL0nCLZ1pfzG
license:              GPL-2.0-or-later AND BSD-3-Clause
maintainer:           hvr@gnu.org, oleg.grenrus@iki.fi
author:               Herbert Valerio Riedel, Oleg Grenrus
homepage:             https://haskell-ci.rtfd.org/
synopsis:             Utilities to work with cabal-install files
description:
    @cabal-install-parsers@ provides parsers for @cabal-install@ files:
    @cabal.project@ ("Cabal.Project"),
    @cabal.config@ ("Cabal.Config"),
    @01-index.tar@ ("Cabal.Index");
    as well as some other utilities.

    The feature set is mainly motivated by the needs of @haskell-ci@ package.
    The parsed data is not complete, functionality is added on demand.

category:             Development
abi:                  bd140d61f229f3770181e68044d44494
exposed:              True
exposed-modules:
    Cabal.Config Cabal.Index Cabal.Optimization Cabal.Package
    Cabal.Parse Cabal.Project Cabal.SourceRepo

hidden-modules:       Cabal.Internal.Glob Cabal.Internal.Newtypes
import-dirs:          /usr/lib/ghc-9.0.2/site-local/cabal-install-parsers-0.4.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cabal-install-parsers-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cabal-install-parsers
hs-libraries:         HScabal-install-parsers-0.4.2-AleMxSwMpbyL0nCLZ1pfzG
depends:
    Cabal-3.4.1.0 aeson-1.5.6.0-6rBoO6bU0Qo8Yma8Si89de base-4.15.1.0
    base16-bytestring-1.0.2.0-L4j4Tjhz2WH6oOCVbuSJzs binary-0.8.8.0
    binary-instances-1.0.2-2uD3sb53b6ULwFrmWq80kw bytestring-0.10.12.1
    containers-0.6.4.1
    cryptohash-sha256-0.11.102.1-Ize6iCswxxswh7KiRPuuP deepseq-1.4.5.0
    directory-1.3.6.2 filepath-1.4.2.1
    lukko-0.1.1.3-CHZ4wwyMfK53p6awgjgCyA
    network-uri-2.6.4.1-BGPJIvUETPDIY3T3wtqoZj parsec-3.1.14.0
    pretty-1.1.3.6 tar-0.5.1.1-HthSwho9hvnDv91yJq0okR text-1.2.5.0
    time-1.9.3 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cabal-install-parsers/html/cabal-install-parsers.haddock

haddock-html:         /usr/share/doc/haskell-cabal-install-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
